#  tests for sas_kernel-2.3.1-py36_1000 (this is a generated file);
print('===== testing package: sas_kernel-2.3.1-py36_1000 =====');
print('running run_test.py');
#  --- run_test.py (begin) ---
import os
import sys
import json

specfile = os.path.join(os.environ['PREFIX'], 'share', 'jupyter', 'kernels', 'sas', 'kernel.json')

with open(specfile, 'r') as fh:
    spec = json.load(fh)

if spec['argv'][0] != sys.executable:
    raise ValueError('The specfile seems to have the wrong prefix. \n'
                     'Specfile: {}; Expected: {};'
                     ''.format(spec['argv'][0], sys.executable))
#  --- run_test.py (end) ---

print('===== sas_kernel-2.3.1-py36_1000 OK =====');
print("import: 'sas_kernel'")
import sas_kernel

